@@ -1,9 +1,15 @@
 package Locale::CLDR::Et::Any;
-# This file auto generated
-#	on Sun 23 Mar  7:34:51 pm GMT
 
-use v5.18;
+# This file auto generated
+#	on Fri 20 Jun 11:27:10 pm GMT
+
+use version;
+
+our $VERSION = version->declare('v0.25.4');
+
+use v5.10;
 use mro 'c3';
+use if $^V ge v5.12.0, feature => 'unicode_strings';
 
 use Moose;
 
